import cv2
import numpy as np

####################
####################

# Input: np color
# Output: color tuple
#         e.g. ([0,0,0]) -> (0,0,0)
def colorSplit(c):
	return tuple([int(x) for x in c])

# Input: color tuple
# Output: np color
#         e.g. (0,0,0) -> ([0,0,0])
def npColor(*c):
	return np.array([*c], dtype=np.uint8)

# Convenience method to create a new mat
# of a supplied size, optionally filled
# with a non-zero color
def newMat(height, width, *c):
	mat = np.zeros((height, width, 3), dtype=np.uint8)
	if len(c):
		mat[:] = npColor(*c)
	return mat

####################
####################

# Assumed to be a map: single character -> (color, cost)
# Default includes blacK, White, Red, Green, Blue
# Changing the value of Blue will affect optimal water path
COST_KWRGB = {
	'K': (npColor(0,0,0), None),
	'W': (npColor(255,255,255), 1),
	'R': (npColor(0,0,255), 100),
	'G': (npColor(0,255,0), 5),
	'B': (npColor(255,0,0), 3),
}

# Input: cost (map, as in COST_KWRGB)
# Output: function that maps a color
#         to a cost (useful for 
#         searching a color-coded maze)
def colorCostFn(costs):
	return lambda color: costs[color][1]

# Input: cost (map, as in COST_KWRGB)
# Output: a map from color character to color code
#         e.g. K -> ([0,0,0])
#         (useful for vizualization independent
#         of action costs)
def colorMap(costs):
	return {ck:cv[0] for ck,cv in costs.items()}

####################
####################

# Convenience function to show a mat
# with a title and optionally wait
# for a supplied time (default: 0)
def showAndWait(mat, title, wait=0):
	cv2.imshow(title, mat)
	if wait is not None:
		cv2.waitKey(wait)

# Convenience function to destroy
# all OpenCV windows
def close():
	cv2.destroyAllWindows()
